#
# spec file for package xfstests
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# We only want DMAPI for SLE11/12
%if 0%{?sle_version} >= 120000 && 0%{?sle_version} < 150000
%define need_dmapi 1
%endif

%if 0%{?sles_version} == 11
%define need_dmapi 1
%endif

%define version_unconverted 1.1.1+git.20190223
Name:           xfstests
Version:        1.1.1+git.20190223
Release:        1.1
Summary:        Filesystem regression test suite
License:        GPL-2.0-or-later
Group:          System/Filesystems
Url:            http://oss.sgi.com/projects/xfs/
Source:         xfstests-%{version}.tar.xz
BuildRequires:  autoconf
BuildRequires:  automake
%if 0%{?need_dmapi}
BuildRequires:  dmapi-devel
%endif
BuildRequires:  e2fsprogs-devel
BuildRequires:  fdupes
BuildRequires:  gdbm-devel
BuildRequires:  libacl-devel
BuildRequires:  libaio-devel
BuildRequires:  libattr-devel
BuildRequires:  libbtrfs-devel
BuildRequires:  libtool
BuildRequires:  m4
BuildRequires:  make
BuildRequires:  openssl-devel
BuildRequires:  xfsprogs-devel
BuildRequires:  xz
Requires:       acl
Requires:       attr
Requires:       bash
Requires:       bc
Requires:       bind-utils
Requires:       btrfsprogs
Requires:       e2fsprogs
Requires:       perl
Requires:       quota
Requires:       xfsdump
Requires:       xfsprogs
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The filesystem regression test suite.  Also includes some support for acl,
attr, dmapi, udf, reiserfs, nfs, btrfs testing.  Contains around 400+ specific
tests for userspace & kernelspace.

%prep
%setup -q

%build
export OPTIMIZER="-fPIC"
export CFLAGS="%{optflags} -Iinclude"
INSTALL_USER=`id -un`
INSTALL_GROUP=`id -gn`
export INSTALL_USER INSTALL_GROUP

# autoreconf doesn't pass -Im4 to aclocal on SLE11
make configure
libtoolize -i
%configure		\
  --disable-static	\
  --exec_prefix=/var/lib
make %{?_smp_mflags} V=1

%install
DIST_ROOT=%{buildroot}
DIST_INSTALL=`pwd`/install.manifest
export DIST_ROOT DIST_INSTALL
make %{?_smp_mflags} DESTDIR=%{buildroot} install DIST_ROOT=%{buildroot} DIST_MANIFEST="$DIST_INSTALL"
make -C build/rpm rpmfiles DESTDIR=%{buildroot} DIST_MANIFEST="$DIST_INSTALL"
%fdupes %{buildroot}/%{_prefix}

%files
%defattr(-,root,root)
/var/lib/xfstests

%changelog
* Mon Feb 25 2019 jeffm@suse.com
- Use 'make configure' instead of 'autoreconf' - autoreconf doesn't
  properly pass -Im4 to aclocal on SLE11.
* Mon Feb 25 2019 jeffm@suse.com
- Update to version 1.1.1+git.20190223:
  * shared/298: Wire btrfs support in get_free_sectors
  * src/Makefile: Link clock_gettime(2) with -lrt
  * src/t_attr_corruption: fix xattr.h include problems
  * fstests: add a seek group
  * xfs/42[01]: remove from the dedup group
  * src/t_open_tmpfiles: flush log when shutting down filesystem
  * xfs/500: fix reflink support detection and add new groups
  * xfs/450: require working falloc command
  * shared: cgroup aware writeback accounting test
  * fsstress: avoid infinite zero byte reading
  * generic: check the behavior of programs opening a lot of O_TMPFILE files
  * inject: skip tests when knob dir exists but knob doesn't
  * generic: posix acl extended attribute memory corruption test
  * generic: check for reasonable inode creation time
  * common: fix _require_btime for lazy filesystems
  * common: fix kmemleak to work with sections
  * xfs: test mkfs extent size hint validation
  * generic/075,112: detect preallocation support for fsx tests
  * btrfs: test for corruption when reading compressed files
  * generic: test fsync after succession of renames and unlink
  * generic: test fsync after succession of file renames
  * src/t_mtab: Add error check for unlock_mtab()
  * xfs/068: Verify actual file count instead of reported file count
  * fstests: Check that high-offset reads and writes work on non-blockdev fs
  * xfs/252: requires fallocate support for preallocation
  * fsstress: avoid splice_f generating too large sparse file
  * overlay/060: Use falloc to make sure a meta copy file got copied up
  * common/dump: do not override test cleanup trap
  * xfs/138: format the scratch device before using it
  * xfs/093: make sure the scratch directory still exists after repair
  * overlay/061: enhance mmap ro/rw inconsistencies test
  * overlay: Do not lose security.capability xattr over metadata only file copy-up
  * btrfs: Test if btrfs will report false ENOSPC error balancing small metadata chunk
  * btrfs: Test if btrfs will commit too many transactions for balance
  * btrfs: Test if btrfs hits EDQUOT without trying to reclaim some space
  * btrfs/131: require support for free-space-tree
  * btrfs/023: skip trying to test raid56 without kernel support
  * btrfs: require feature raid56 for raid56 tests
  * btrfs/010: don't run without /sys/fs/btrfs
  * btrfs/081: fix killing of reader loop subshell
  * btrfs/081: declare local variables as local
  * common/dump: disable splice from FSSTRESS_AVOID
  * fsstress: add splice support
  * overlay: File capabilities should not be lost over copy-up
  * generic: test writepage cached mapping validity
  * btrfs: test for deadlock between snapshot delete and other read-write operations
  * btrfs: Make seed device test cases into their own group
  * generic: test that xattrs can have slashes in their names
  * generic/423: statx mask of the reference file is different from the original file
  * Revert "common/config: create $RESULT_BASE before dumping kmemleak leaks"
  * generic/131: wait until the server is ready or timeout
  * fsx: check ENOSYS in test_copy_range() & test_fallocate()
  * xfs/139-140: skip testing on large scratch dev
  * generic/474: shift target directory to a sub-dir of SCRATCH_MNT
  * xfs: only set XFS_MKFS_HAS_NO_META_SUPPORT for XFS
  * generic/466: explicitly request $SCRATCH_DEV to be a block device
  * generic/019: require scratch device to be a block device
  * check: use _try_scratch_mount instead of _scratch_mount to mount SCRATCH_DEV
  * ext4/034: adjust commit which fixes the problem tested by ext4/034
  * xfs: look for stringified constants in ftrace formats
  * xfs: filter out mount options that don't work on v4 filesystems
  * generic/050: fix ro blockdev mount of xfs with quota
  * xfs/123: fix remote symlink block size calculation
  * xfs/111: fix golden output
  * check: fix -X exclude_file behaviour
  * common: Fix mismatched output from standard mkswap
  * common/config: create $RESULT_BASE before dumping kmemleak leaks
* Wed Dec 19 2018 jeffm@suse.com
- Update to version 1.1.1+git.20181214:
  * generic/062, 520: Don't remove lost+found during cleanup
  * generic: long fsx soak tests
  * common/dump: disable copyrange
  * fsx: add copy_file_range support
  * fsstress: add copy_file_range support
  * fsx: add FIDEDUPERANGE support
  * fsx: add FICLONERANGE support
  * fsx: add five-argument logging function
  * fsx: use an enum to define the operation commands
  * fsx: always check buffer after each operation
  * fsx: shut up compiler warnings
  * fsstress: check system call return values
  * fsstress: fix compiler warnings
  * fstest: CrashMonkey 'hard link' tests ported to xfstest
  * ext4/002: Fix obsolete TEST_DEV/TEST_DIR in _check_ext4_eof_flag()
  * ext4/021: Work with 64k block size
  * ext4/002: Work with 64k block size
  * common/rc: Add _require_filefrag_options() to check options for filefrag
  * src/t_stripealign.c: Use block size reported by fstatfs()
  * xfs: Fix the situation that mount operation rejects corrupted XFS
  * xfs: xfs_fsr requires working preallocation support
  * xfs: don't assume preallocation is always supported on XFS
  * generic: don't assume preallocation is supported when reflinks are supported
  * btrfs: test send after radical changes in a complex directory hierarchy
  * xfs/205: Fix that b2 variable is treated as octal vaule
  * overlay: create directory over deleted whiteout
  * ext4/034: filter out the specified vaule of $SCRATCH_MNT
  * ext4: regression test for a ENOSPC warning
  * generic/398: filter out extra string from newer mv
  * btrfs: test balance and resize with an active swap file
  * btrfs: test device add/remove/replace with an active swap file
  * btrfs: test swap files on multiple devices
  * btrfs: test invalid operations on a swap file
  * btrfs: test swap file activation restrictions
  * btrfs: fix computation of max fs size for multiple device fs tests
  * generic: verify FIBMAP address overlap
  * populate: fix leafn creation test for v4 filesystems
  * btrfs: add new filter for file cloning error translation
  * generic: test attempt to reflink eof block into the middle of a file
  * generic: test attempt to dedup eof block into the middle of a file
  * overlay: test file handle decode with multi lower layers on same fs
  * generic/{472,496}: fix swap file creation on Btrfs
  * generic/{472,496,497}: fix $seeqres typo
  * misc: force the exact quota options coded into the test
  * xfs/205: update for v5 filesystems
  * xfs/266: fix restore summary counter when quotas are enabled
  * dump: don't fail if multi-file dumps don't all contain quota info
  * xfs: force unlink metadata updates to disk
  * quota: clean out speculative preallocations when checking quota usage
  * xfs: fuzz directories containing single leafn blocks
  * xfs: test repair regression of dir w/ single leafn block
  * populate: create leafn dir when populating xfs filesystem
  * xfs: test packaged crc32c code
  * check: use full paths for diff on error
  * fstests: fix fssum to actually ignore file holes when supposed to
  * btrfs/057: Fix false alerts due to orphan files
  * generic: update group file to indicate generic/456 uses {collapse,zero}_range
  * fstests: add some tests to the 'log' group that use dmflakey
  * btrfs: fix classification of a couple btrfs tests
  * generic/508: fix to check inode creation time feature on scratch mountpoint
* Mon Oct 22 2018 jeffm@suse.com
- Update to version 1.1.1+git.20181021:
  * generic: test reflink side effects
  * btrfs: fix test btrfs/007 to not leave temporary files in /tmp
  * generic: test fsync after fallocate on a very small file
  * xfs/140: work with 1k block size
  * xfs/139: work with 1k block size
  * src/fiemap-tester: fix getting blocksize on overlayfs
  * xfs/288: shut up verifier error
  * xfs/270: use _scratch_xfs_set_metadata_field to fuzz rocompat bits
  * xfs/189: skip 'barrier' mount option test on newer kernels
  * xfs: test mount time summary counter check and fix
  * generic: another mread-after-eof test
  * geneirc/077: fix min size for btrfs
  * generic: test for file fsync after moving it to a new parent directory
  * generic: test mounting filesystem after fsync of a tmpfile
  * common/rc: fix check for yp
  * common/reflink: fix error messages in _require_scratch_dedupe()
  * ext4/018: fix mismatch wildcard with debugfs
  * generic: test creation time recovery after power failure
  * generic: test i_flags recovery after power failure
  * generic: test project id recovery after power failure
  * generic/387: fix _scratch_mkfs_sized option for btrfs
  * generic/449: fix fs size for _scratch_mkfs_sized for btrfs
  * generic/083: fix btrfs fs size for default mode
  * generic/015: fix to test the default non-mixed mode
  * btrfs: _scratch_mkfs_sized fix min size without mixed option
  * btrfs: test unaligned punch hole at ENOSPC
  * xfs/122: add struct xfs_unmount_log_format
  * common/quota: adapt _require_prjquota() for f2fs
  * generic/108: work with 64k block size
  * generic/018: to work with 64k block size
  * generic/459: work with 64k block size
  * generic/235: work with 64k block size
  * generic/230: work with 64k block size
  * generic/177: work with 64k block size
  * common/punch: Filter fiemap output by FS block size
  * generic/172: work with 64k block size
  * generic/102: work with 64k block size
  * xfs/325: Inject free_extent error after CoW operation
  * xfs/299: work with 64k block size
  * xfs/299: Fix "Push past soft inode limit" case
  * xfs/190: work with 64k block size
  * xfs/140: work with 64k block size
  * xfs/139: work with 64k block size
  * xfs/127: work with 64k block size
  * xfs/074: work with 64k block size
  * xfs/050: work with 64k block size
  * xfs/050: Fix "Push past soft inode limit" case
  * xfs/009: work with 64k block size
  * generic: test uid/gid recovery after power failure
  * xfs/270: allow corrupted xfs_db write
* Tue Sep 25 2018 jslaby@suse.cz
- Update to version 1.1.1+git.20180923:
  * fstests: fix _test_generic_punch() to fit 64k extent
  * common/rc: fix check for disabled kmemleak
  * btrfs/149: make it sectorsize independent
  * shared/010: avoid dedupe testing blocked on large fs
  * generic/498: don't call _cleanup_flakey repeatedly
  * tmpfs: don't require {TEST|SCRATCH}_DEV
  * generic/504: Check inode number accurately
  * generic/009: fix test failure with overlay over ext4
  * overlay: do not set OVL_BASE_FSTYP value to "overlay"
  * src/seek_sanity_test: skip test20 if file's too big
  * overlay/016: split into two tests
  * open_by_handle: fix name of directory in error messages
  * fstests: filter redundant output by getfattr
  * fstests: Fix buffer alignment of aiocp
  * btrfs: Add test for corrupted childless qgroup numbers
  * generic: show locks info owned by dead process
  * xfs/288: notrun if xfs_db write command fails
  * generic/228: fix restoration of kernel.core_pattern sysctl
  * src/stat_test: fix undefined reference to `xfstests_statx'
  * btrfs: test writing into unwritten extent right before snapshotting
  * xfs: test inode allocation state missmatch corruption
  * btrfs/057: Update test case to keep subvolume in any kernel version
  * btrfs: test send with prealloc extent beyond EOF and hole punching
  * xfs/288: use -d option of xfs_db write command for v5 XFS
  * generic: test DAX DMA vs truncate/hole-punch
  * btrfs: test send with snapshots that have files deleted while open
  * generic: add test for fsync after renaming hard links of same file
  * build: replace lowercase letters regex with POSIX character class in Makefile
  * src/: add license and copyright info to files
  * generic: add test for fsync after cloning file range
  * common: filter out quota regeneration messages
  * generic/338: don't check fs after crashing it
  * xfs/288: update for v5 filesystem support in xfs_db
  * xfs/001: update to handle v5 filesystems
  * generic/{279, 28[1-3]}: hide SIGBUS reporting from golden output
  * generic: test dm-thin running out of data space vs concurrent discard
  * common/xfs: remove bad xfs_repair -t option
  * generic/499: filter fsx stderr output
  * xfs: fuzz every field of every structure and test kernel crashes
  * nfs/001: ignore the header in nfs4_getfacl output
  * xfs: skip copy fs test on large device
  * generic: mread past eof shows nonzero contents
  * xfs/262: remove -y parameter
  * build: fix undefined macro: AC_PACKAGE_NEED_GETXATTR_LIBATTR
  * build: remove <attr/xattr.h> check
  * src/t_immutable: use sys/xattr.h instead of attr/xattr.h
  * fsstress: remove include <attr/xattr.h>
  * btrfs: test if btrfs will corrupt nodatasum compressed extent when replacing device
  * build: fix install target using sudo
  * xfs: test bad character in xfs_db field list selector string
  * btrfs: test power failure while qgroups rescan is in progress
  * common: Add _dmsetup_create and _dmsetup_remove helpers
  * shared: dedupe with random io race test
  * shared: iterate dedupe integrity test
  * shared: dedupe a single big file and verify integrity
  * xfs: Test root inode parent pointer repairing
  * xfs: regression test for rmapbt fdblocks accounting problems
  * fstests: add SPDX license comments for src/log-writes/*
  * xfs/365: fuzz inobt in ag 1
  * ltp/: spdx license conversion
  * src/: spdx license conversion
  * src/aio-dio-regress/: spdx license conversion
  * lib/: spdx license conversion
  * include/: spdx license conversion
  * dmapi: spdx license conversion
  * src: fix up mmap() error checking
  * common/xfs: Add _scratch_get_sfdir_prefix function
  * btrfs: replace btrfs-debug-tree with btrfs inspect-internal dump-tree
  * src/t_stripealign.c: Fix complier error
  * xfs/170: increase agsize for bigger internal log size
  * generic/223: port t_stripealign to FIEMAP
  * btrfs: Add test that checks rmdir(2) can delete a subvolume
  * ltp/fsx: output the seed value after logid is initialized
  * generic: add test for fsync of directory after creating hard link
  * generic/391: add _require_odirect
  * common: improve regex in _check_dmesg
  * fstests: make lsqa.pl work with SPDX tags
  * fstests: convert top level files and tools to SPDX
  * fstests: convert remaining tests to SPDX license tags
  * btrfs: convert tests to SPDX license tags
  * xfs: convert tests to SPDX license tags
  * generic: convert tests to SPDX license tags
  * fstests: convert new test template to SPDX tags
  * common: convert to SPDX license tags
  * fstests: Add LICENSES directory
  * generic: test swapfile creation, activation, and deactivation
  * xfs: make sure pretty printed geometry output matches
  * xfs: abstract xfs_info into $XFS_INFO_PROG
  * xfs/310: fix _require_scratch_nocheck ordering
  * xfs/122: fix sb_fname[XFSLABEL_MAX] in test
  * xfs/439: don't check filesystem afterwards
  * generic/401: fix test in case of no filetype support
  * overlay: nicer report when features are not supported
  * common/rc: skip atime related tests on CIFS
  * xfs: Regression test for vulnerable directory integrity check
  * common/rc: Fix _require_xfs_io_command for scrub probe
  * check: fail tests if check/dmesg are not clean
  * overlay: Add tests for overlay metadata only copy up feature
  * btrfs: introduce btrfs/volume group
  * btrfs: seed device delete test
  * btrfs: seed device replace test
  * btrfs: nested seed device test
  * btrfs: add seed sprout functionality test
  * generic/009: don't run for btrfs if PAGE_SIZE > 4096
  * ext4/306: Fixup resize2fs usage
  * ext4/010: Fixup resize2fs and dumpe2fs usage
  * ext4/032: Fix up resize2fs usage
  * xfs/310: Cleanup
  * ext4: Test for s_inodes_count overflow during fs resize
  * dmhugedisk: Allow specifying of chunk size
  * fstests: Make ./new work for non-root user
  * fstests: get rid of set_prog_path
  * fstests: update the punch, collapse, insert, and zero groups
  * xfs/206: filter/fix for minor geometry reporting changes
  * generic/484: Need another process to check record locks
  * xfs/447: fix typo
  * check: Make the test harness unmount fs when finishing a test
  * generic: test invalid swap file activation
  * generic: add test for truncate/fpunch of an active swapfile
  * generic: add test for dedupe on an active swapfile
  * generic: enable swapfile tests on Btrfs
  * fstests: create swap group
  * generic/475: fix confusing comment
  * generic/490: fix cleanup function
  * common/quota: sort lines of repquota output
  * generic: drop test 472
  * generic: add tests 405 and 459 to the group 'thin'
  * report: make sure control charcters are encoded in xUnit report
  * generic: Handle missing [gs]etcap tools
  * generic: test online label ioctl
  * generic/459: use xfs_freeze instead of fsfreeze
  * generic/486: Get rid of the redundant error=%%d printing
  * common/quota: Fix _qmount_options for ext4 journalled quotas
  * common/quota: Make project quota handling work for ext2 & ext3
  * generic: test first read with freeze right after mount
  * fstests: define and use TIMEOUT_PROG
  * generic: Add SEEK_DATA tests for offsets in the middle of holes
  * generic: test for fsync of file with xattrs
  * xfs: test mount vs superblock shrinker races
  * btrfs: test ENOSPC caused by many orphan items
  * xfs: skip growfs test on large device
  * generic/484: add missing _require_test_program
  * btrfs: add test for seeing unseen fsync errors on newly open files
  * generic: test for seeing unseen fsync errors on newly open files
  * xfs: checkbashisms in all script files
  * generic/{159,160}: require chattr instead of lsattr
  * common/rc: decouple xfs_io flink check from xfs_io -T check
  * xfs: test inobt/on disk free state mismatches
  * fstests: many dangerous+auto tests are not dangerous anymore
  * fstests: remove old electric fence support
  * overlay: test multiple origin references to the same lower file
  * overlay/049: update fix commit id
* Mon May  7 2018 dsterba@suse.cz
- Update to version 1.1.1+git.20180506
* Wed Mar 14 2018 jeffm@suse.com
- Only require dmapi-devel for SLE11/12.
* Wed Mar 14 2018 opensuse-packaging@opensuse.org
- Update to version 1.1.1+git.20180308:
  * btrfs/146: make sure hit all stripes in the case of compression
  * btrfs/004: increase the buffer size of logical-resolve to the maximum value 64K
  * generic: test fsync new file after removing hard link
  * generic: add test for fsync after renaming and linking special file
  * overlay: correct scratch dirs check
  * overlay: skip check for tests finished with corrupt filesystem
  * overlay/003: fix fs check failure
  * overlay: hook filesystem check helper
  * common/rc: improve dev mounted check helper
* Tue Feb 27 2018 opensuse-packaging@opensuse.org
- Update to version 1.1.1+git.20180224:
  * fsstress: avoid infinite loops in clonerange_f
  * generic/47[23]: remove from auto/quick groups
  * common/xfs: Initialise OPTIND for getopts calls
  * common/rc: Fix fcollapse require code to work with 64k block size
  * fsx: Fix -P errors
  * fstests: _fail test by default when _scratch_mount fails
  * generic/25[02]: increase filesystem size
  * btrfs/150: add _scratch_dev_pool_get/put to run the test as expected
  * xfs/015: enlarge the initial fs size
  * generic: add OFD lock tests
  * xfs: rmapbt swapext block reservation overrun test
  * xfs: regression tests for reflink quota bugs
  * xfs/348: dir->symlink corruption must not be allowed
  * xfs_scrub: remove -y parameter
  * overlay: renumber tests after merge
  * overlay: add fsck.overlay impure xattr test
  * overlay: add fsck.overlay redirect directory test
  * overlay: add fsck.overlay whiteout test
  * overlay: define common overlay xattr keys
  * overlay: add filesystem check helper
  * generic/270: Check for scratch mount success
  * check: Fix exit status
  * overlay: test overlay file handle of dir with ancestor under lower redirect
  * overlay: test overlay file handles of lower dir with non-indexed ancestor
  * generic/{274,315}: Require falloc -k support
  * generic/307: Require ACL support
  * overlay: test encode/decode of non-samefs overlay file handles with renames
  * overlay: test encode/decode overlay file handles with renames
  * overlay: test encode/decode of non-samefs overlay file handles
  * overlay: test encode/decode overlay file handles
  * fstests: implement require of multiple overlayfs features
  * overlay: add a test for multiple redirects to the same lower dir
  * overlay/017: require and enable redirect_dir
  * overlay: consider index dir with whiteouts clean
  * overlay/036: fix upper/lower dir mismatch
  * ovelray: drop explicit use of OVERLAY_MOUNT_OPTIONS
  * src/metaperf: Include linux/param.h explicitly for HZ macro
  * src/dmiperf: Include sys/types.h for u_int32_t
  * xfs/24[356]: checking cow fork bmap requires CONFIG_XFS_DEBUG=y
  * generic/403: don't spew '$GETFATTR_PROG: Killed' messages
  * xfs/122: fix xfs header ordering problems
  * common/rc: report kmemleak errors
  * ext4: Ext4 online resize with bigalloc tests.
  * generic: test decoding file handles after cycle mount
  * generic/exportfs: golden output is not silent
  * src/open_by_handle: verify dir content only with -r flag
  * src/pwrite_mmap_blocked: Include signal.h instead of sys/signal.h
  * src/t_mtab: Replace sys_siglist[] with strsignal()
  * src/fssum: Use htobe64() instead of a custom macro
  * doio, growfiles: Use standard signal name SIGCHLD instead of SIGCLD
  * fstests: Replace all __[u]intNN_t types with standard [u]intNN_t
  * fsstress: Include stddef.h for ptrdiff_t
  * check: expunge tests when doing a dry run
  * check: move expunge test into a helper
  * xfs: Regression test for invalid sb_logsunit
  * common: Add _require_no_xfs_bug_on_assert and factor out filter_xfs_dmesg
  * xfs/realtime: Fix direct invocations of xfs_repair
  * xfs/realtime: add _require_no_rtinherit function
  * xfs/realtime: Add require_no_realtime function
  * common/dmthin: dm-thin lacks DAX support
  * common/xfs: Check if write supports [-c|-d] option in xfs_db
  * shared/272: don't use data journaling with DAX
  * btrfs/027: unmount scratch device if test fails
  * btrfs/011: umount device in _cleanup
  * fstests: Add 9p network filesystem support
  * generic/015: Change the test filesystem size to 101mb
  * filter: Introduce filter to filter out offset for xfs_io
  * xfs: test for umount hang caused by the pending dquota log item in AIL
  * common/rc: factor out _scratch_xfs_[get|set]_sb_field
  * dmflakey: support error_writes feature for dm-flakey
  * dmflakey: support multiple dm targets for a dm-flakey device
  * common/rc: ext4 doesn't support O_DIRECT with data journaling
  * common/rc: perform _require_metadata_journaling check on overlay base fs
  * xfs: find libxfs api violations
  * ext4: test for inline data + DAX corruption
  * ext4: test for DAX + journaling corruption
  * xfs/068: fix clonerange problems in file/dir count output
  * btrfs: make sure scrub fixes raid6 corruption
  * generic: run a long-soak write-only fsstress test
  * generic/050: fix _require_local_device $SCRATCH_DEV check order
  * fsstress: implement the clonerange/deduperange ioctls
  * generic: test error shutdown while stressing filesystem
  * ext4: use a slightly bigger file system in ext4/021
  * common/encrypt: Create an encrypted equivalent of _scratch_mkfs_sized
  * btrfs: Add new 'limit' test group for btrfs
  * xfs/040: document purpose
  * generic: add syncfs test
  * common/rc: check syncfs support
  * common/rc: add scratch shutdown support for overlayfs
  * fsstress: getcwd() return value fixes
  * fsstress: Eliminate valgrind noise
  * README: document group fsgqa is required
  * xfs: fix tests to handle removal of no-alloc create nonfeature
  * generic/45[34]: test line draw characters in file/attr names
  * common/xfs: fix scrub support probing again
  * build: update AC_PACKAGE_WANT_GDBM() and src/dbtest.c to build
  * generic/group: add 304 to dedupe group
  * generic: initial fiemap range query test
  * generic: Partial direct write test
  * generic: Test RWF_NOWAIT
  * common/rc: Check pwrite parameters in _require_xfs_io_command
  * common/populate: fix S_IFDIR.FMT_BLOCK and ATTR.FMT_LOCAL for ext4 encryption
  * common: rework _require_ext4_mkfs_feature
* Mon Dec 11 2017 dsterba@suse.cz
- Update to git version 20171210
- spec: fix build problems since the last upstream update
- Removed patches: no-ltinstall.diff, not needed anymore
* Sun Jan 29 2017 mpluskal@suse.com
- Update to version 1.1.1+git.20170127:
  * populate: discover XFS structure fields and fuzz verbs, and use them to fuzz fields
  * common/populate: create attrs in different namespaces
  * xfs: fuzz every field of every structure
  * fstests: fix wrong seq number in test
  * mvtest: change "FSQA Test No." when we renumber tests
  * xfs: test xfs_db source command
  * tools/nextid: pad 0 in next test id seq number
  * xfs/122: reduce xfs_dsb_t size
  * btrfs: setxattr on subvolume directory
  * generic: splitted large dio write could trigger assertion on btrfs
* Thu Nov 24 2016 dsterba@suse.cz
- Update to version 1.1.1+git.20161118:
  * xfs/021: filter out detailed array element info from xfs_db
  * xfs: testcase for kernelspace xfs_fsr extent handling flaw
  * fstests: fix fsx fallocate error messages
  * generic/37[3-4]: use bind mount instead of 2nd _scratch_mount
  * generic/38[3-6]: require project quota to be enabled on SCRATCH_DEV
  * generic: fix $tmp path in tests
  * xfs/298: cd to / instead of ~
  * generic/098: update test for truncating a file into the middle of a hole
  * generic: concurrent non-overlapping direct I/O on the same extents
  * fstests: Introduce check for explicit SHARED extent flag reporting
* Tue Oct  4 2016 mpluskal@suse.com
- Update to version 1.1.1+git.20160924:
  * xfs: various operations on mounted fs
  * common/rc: fix fsmap check
  * fstests: require scratch dev in tests using dm targets
  * xfs/260: fix output to match actions
  * xfs: modify quota tests to work on generic filesystems
  * fstests: move now-generic quota tests to generic
  * xfs: make some xfs project quota tests generic
  * fstests: move now-generic xfs project quota tests generic
  * generic: truncate heavily reflinked file
  * btrfs: test free space tree mount options
* Tue Oct  4 2016 mpluskal@suse.com
- Update to version 1.1.1+git.20160817:
  * xfs/234: use scratch device helpers
  * common/rc: optionally test xfs_repair index rebuilding
  * xfs/128: cycle_mount the scratch device
  * common/dmerror: fix mount option issues
  * xfs: test attr_list_by_handle cursor iteration
  * common/defrag: rework _require_defrag for ext4
  * ext4: Test expansion of inode size
  * generic: test accurate shared extent reporting
  * README: document Fedora, RHEL, and CentOS dependencies
  * fstests: repository @ oss.sgi.com no longer used
* Thu Jul 28 2016 mpluskal@suse.com
- Update to version 1.1.1+git.20160721:
  * generic/294: filter quotes from mknod
  * common/rc: ext4 doesn't support O_DIRECT with encryption
  * generic/082: rename _filter_project_quota to a avoid function name conflict
  * fstests: Add / use _require_runas and _runas
  * generic: Add richacl tests
  * btrfs/048: extend _filter_btrfs_prop_error to handle additional errors
  * generic/042: remove from quick group
  * overlay: dentry leak for default_permissions mount option
  * overlay: remove dir which contains whiteout from lower dir
  * common: support dm-delay to introduce I/O delays
  * xfs: test for post umount readahead completion panic
  * btrfs: add functions to set and reset required number of SCRATCH_DEV_POOL
  * btrfs: add functions to get and put a device for replace target
  * btrfs/027: make use of new device get and put helper functions
  * btrfs: add helper function to check if btrfs is module
  * btrfs: test RAID1 device reappear and balance
  * btrfs: test RAID5 device reappear and balance
  * btrfs: EDQUOTA leaks reserved data space
  * quota: fix generic/244 on 32-bit platforms
  * common/dmerror: fix nonsensical arguments handling
  * xfs: configurable behavior on errors at unmount time
  * xfs/122: fix test output to reflect latest xfsprogs
  * xfs/235: fix logic errors when checking rmap usage after failures
  * xfs/229: require 3GB of space
  * generic/204: increase log size for rmap/reflink
  * xfs/128: use $XFS_FSR_PROG instead of xfs_fsr directly
  * xfs: inject errors at various parts of the deferred op completion
  * xfs: test clearing reflink inode flag
  * ext4/021: add _require_metadata_journaling
  * btrfs/079: Fix wrong value passed to available space check
  * btrfs: incremental send after moving directories around
  * btrfs: incremental send after removing a directory
  * btrfs: invalid rmdir issued by send operation
  * common/rc: add _require_xfs_mkfs_validation
  * xfs/096: run test only if mkfs.xfs accepts invalid inputs
  * generic: add _require_block_device to more tests
  * common/rc: avoid mkfs option conflicts in _scratch_mkfs_xfs_supported
  * xfs: fix wrong seq order in group file
  * generic/120: requires working *atime mount options
  * build: Fix installation for extended names
  * check: fix extended names handling
  * check: remove unused variable
  * xfs: Add mkfs input validation tests
  * xfs/083: disable dmesg check
  * btrfs: send on fully deduped file
  * generic/075,112: fix up fsx error handling
  * generic/294: Filter backquotes from mknod error output
  * common/filter: Improve xfs_io filter
  * btrfs: Update quick and auto tag for btrfs group
  * generic/235: Fix false failures for some quota formats
* Sun Jul  3 2016 mpluskal@suse.com
- Update to version 1.1.1+git.20160624:
  * xfs/186: fix test for crc=0, ftype=1
  * xfs/186: run test on expected XFS configuration
  * dmthin: express low_water in cluster_size not sector size
  * generic/026: This test doesn't require runas
  * overlay: test visible whiteout issue after rename
  * overlay: getcwd() after a failed rmdir
  * overlay: create new file over whiteout
  * btrfs/006: ignore btrfs filesystem sync stdout output
  * fstests: introduce _exclude_scratch_mount_option helper
  * ext4/271: _notrun if there are journal related mount options
* Mon May  9 2016 mpluskal@suse.com
- Update to version 1.1.1+git.20160509:
  * dm-thinp demo test
  * overlay: test basic whiteout
  * overlay: notrun if upper fs does not support d_type
  * overlay: test copy up by changing mode bits
  * btrfs: Test that qgroup counts are valid after snapshot creation
  * generic: test creating a symlink and then fsync its parent directory
  * btrfs: add replace missing and replace RAID 5/6 to profile configs
  * btrfs: add test for replacing a missing device
  * fstests: fix various $seqres.full issues
  * generic: renumber tests after merge
* Wed Apr  6 2016 mpluskal@suse.com
- Update to version 1.1.1+git.20160405:
  * lib/tlibio: Fix a build warning
  * btrfs: test log replay with qgroups enabled and orphan roots
  * generic/338: Add mmap race test
  * common: make sure dm device is all settled before removing it
  * btrfs: add test for fsync after snapshot deletion
  * check: make results/check.log match everybody else
  * common: replace chattr with $CHATTR_PROG
  * generic/244: avoid creating too large random ID
  * xfs/206: filter out reflink related outputs
  * generic: add test for fsync after renaming directory
  * generic: add test for fsync after renaming file
  * xfs/030: filter out repeated lines from .out files
  * attr: adjust acl_max of f2fs if inline_xattr is set
  * common: Mark tests which use direct I/O with _requires_odirect
  * generic/082: filter out project quota status
* Fri Apr  1 2016 mpluskal@suse.com
- Update to version 1.1.1~git.20160323:
- Replace export-xfstests-git.sh with _service
- Cleanup spec file with spec-cleaner
- Make building more verbose
* Tue Mar 22 2016 dsterba@suse.cz
- update to git b90938ec1de6
* Tue Feb 23 2016 dsterba@suse.cz
- update to git fdf1c150a0e0
* Mon Feb 15 2016 dsterba@suse.cz
- update to git 74b326f9a616
* Mon Feb  8 2016 dsterba@suse.cz
- update to git d98149c20555
- add more dependencies to build fssum and dbtest
* Sun Nov  1 2015 dsterba@suse.cz
- update to git 8deb63509840
* Sun May 31 2015 dsterba@suse.cz
- update to git 78bbab93d8e8
* Thu May  7 2015 dsterba@suse.cz
- update to git c3d3e1e4bc06
* Tue Apr  7 2015 dsterba@suse.cz
- update to git facff609afd6
* Tue Mar  3 2015 dsterba@suse.cz
- update to git e020a49a70b3
* Wed Jan 28 2015 dsterba@suse.cz
- update to git 573f9ca7bc53
* Thu Dec 18 2014 dsterba@suse.cz
- update to git 46a08542e342
* Fri Oct 17 2014 dsterba@suse.cz
- update to git 481c28f52fd4
* Fri Oct  3 2014 dsterba@suse.cz
- update to git 48c45430ce4b
- spec: require the basic filesystem tools
* Mon Sep  8 2014 dsterba@suse.cz
- update to git f7d0a306291a
* Tue Jul 22 2014 dsterba@suse.cz
- update to git c728752cfaab
* Fri Mar 21 2014 dsterba@suse.cz
- update git exporter
- update to 1.1.1, git snapshot f1dcf49c11eb
- spec cleanup
* Sat May 26 2012 jengelh@inai.de
- Remove redundant tags/sections from specfile
- Parallel build with %%_smp_mflags
- Remove non-existing Buildrequired packages
* Thu Nov  3 2011 dsterba@suse.cz
- update to git 868a386
- time to change changelog time
* Fri Oct 14 2011 dsterba@suse.cz
- update to git 73a57c6
- This is the firsteversioned release recorded for the
  xfstests suite.  Tests 240-263 have been added to the
  suite (to date) in 2011.
* Mon Aug 15 2011 dsterba@suse.cz
- update to git 1a9e9e0
* Mon Aug 15 2011 dsterba@suse.cz
- update to git d6f51d9
* Mon Aug 15 2011 dsterba@suse.cz
- update to git 314b221
* Mon Aug 15 2011 dsterba@suse.cz
- update to git 99102d6
* Mon Aug 15 2011 dsterba@suse.cz
- update to git de164fb
* Mon Aug 15 2011 dsterba@suse.cz
- update to git 392c442
* Mon Aug 15 2011 dsterba@suse.cz
- initial checkin
